@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -58,7 +58,10 @@ class VizierServiceClientMeta(type):
     _transport_registry["grpc"] = VizierServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = VizierServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[VizierServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[VizierServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -167,10 +170,16 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def custom_job_path(project: str, location: str, custom_job: str,) -> str:
+    def custom_job_path(
+        project: str,
+        location: str,
+        custom_job: str,
+    ) -> str:
         """Returns a fully-qualified custom_job string."""
         return "projects/{project}/locations/{location}/customJobs/{custom_job}".format(
-            project=project, location=location, custom_job=custom_job,
+            project=project,
+            location=location,
+            custom_job=custom_job,
         )
 
     @staticmethod
@@ -183,10 +192,16 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def study_path(project: str, location: str, study: str,) -> str:
+    def study_path(
+        project: str,
+        location: str,
+        study: str,
+    ) -> str:
         """Returns a fully-qualified study string."""
         return "projects/{project}/locations/{location}/studies/{study}".format(
-            project=project, location=location, study=study,
+            project=project,
+            location=location,
+            study=study,
         )
 
     @staticmethod
@@ -199,10 +214,18 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def trial_path(project: str, location: str, study: str, trial: str,) -> str:
+    def trial_path(
+        project: str,
+        location: str,
+        study: str,
+        trial: str,
+    ) -> str:
         """Returns a fully-qualified trial string."""
         return "projects/{project}/locations/{location}/studies/{study}/trials/{trial}".format(
-            project=project, location=location, study=study, trial=trial,
+            project=project,
+            location=location,
+            study=study,
+            trial=trial,
         )
 
     @staticmethod
@@ -215,7 +238,9 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -228,9 +253,13 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -239,9 +268,13 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -250,9 +283,13 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -261,10 +298,14 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -451,6 +492,34 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         r"""Creates a Study. A resource name will be generated
         after creation of the Study.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_create_study():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                study = aiplatform_v1beta1.Study()
+                study.display_name = "display_name_value"
+                study.study_spec.metrics.metric_id = "metric_id_value"
+                study.study_spec.metrics.goal = "MINIMIZE"
+                study.study_spec.parameters.double_value_spec.min_value = 0.96
+                study.study_spec.parameters.double_value_spec.max_value = 0.962
+                study.study_spec.parameters.parameter_id = "parameter_id_value"
+
+                request = aiplatform_v1beta1.CreateStudyRequest(
+                    parent="parent_value",
+                    study=study,
+                )
+
+                # Make the request
+                response = client.create_study(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CreateStudyRequest, dict]):
                 The request object. Request message for
@@ -514,7 +583,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -530,6 +604,25 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> study.Study:
         r"""Gets a Study by name.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_get_study():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.GetStudyRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_study(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.GetStudyRequest, dict]):
                 The request object. Request message for
@@ -583,7 +676,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -600,6 +698,26 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         r"""Lists all the studies in a region for an associated
         project.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_studies():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListStudiesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_studies(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListStudiesRequest, dict]):
                 The request object. Request message for
@@ -659,12 +777,20 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListStudiesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -681,6 +807,22 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> None:
         r"""Deletes a Study.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_delete_study():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.DeleteStudyRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_study(request=request)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.DeleteStudyRequest, dict]):
                 The request object. Request message for
@@ -732,7 +874,10 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def lookup_study(
@@ -747,6 +892,26 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         r"""Looks a study up using the user-defined display_name field
         instead of the fully qualified resource name.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_lookup_study():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.LookupStudyRequest(
+                    parent="parent_value",
+                    display_name="display_name_value",
+                )
+
+                # Make the request
+                response = client.lookup_study(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.LookupStudyRequest, dict]):
                 The request object. Request message for
@@ -801,7 +966,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -820,6 +990,31 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         long-running operation succeeds, it will contain a
         [SuggestTrialsResponse][google.cloud.ml.v1.SuggestTrialsResponse].
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_suggest_trials():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.SuggestTrialsRequest(
+                    parent="parent_value",
+                    suggestion_count=1744,
+                    client_id="client_id_value",
+                )
+
+                # Make the request
+                operation = client.suggest_trials(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.SuggestTrialsRequest, dict]):
                 The request object. Request message for
@@ -859,7 +1054,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -884,6 +1084,25 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> study.Trial:
         r"""Adds a user provided Trial to a Study.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_create_trial():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.CreateTrialRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_trial(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CreateTrialRequest, dict]):
                 The request object. Request message for
@@ -950,7 +1169,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -966,6 +1190,25 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> study.Trial:
         r"""Gets a Trial.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_get_trial():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.GetTrialRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_trial(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.GetTrialRequest, dict]):
                 The request object. Request message for
@@ -1024,7 +1267,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1040,6 +1288,26 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> pagers.ListTrialsPager:
         r"""Lists the Trials associated with a Study.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_trials():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListTrialsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_trials(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListTrialsRequest, dict]):
                 The request object. Request message for
@@ -1099,12 +1367,20 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListTrialsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1122,6 +1398,25 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         Trial. This measurement is assumed to have been taken
         before the Trial is complete.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_add_trial_measurement():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.AddTrialMeasurementRequest(
+                    trial_name="trial_name_value",
+                )
+
+                # Make the request
+                response = client.add_trial_measurement(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.AddTrialMeasurementRequest, dict]):
                 The request object. Request message for
@@ -1162,7 +1457,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1177,6 +1477,25 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> study.Trial:
         r"""Marks a Trial as complete.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_complete_trial():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.CompleteTrialRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.complete_trial(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CompleteTrialRequest, dict]):
                 The request object. Request message for
@@ -1215,7 +1534,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1231,6 +1555,22 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> None:
         r"""Deletes a Trial.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_delete_trial():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.DeleteTrialRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_trial(request=request)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.DeleteTrialRequest, dict]):
                 The request object. Request message for
@@ -1281,7 +1621,10 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def check_trial_early_stopping_state(
@@ -1297,6 +1640,29 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         will contain a
         [CheckTrialEarlyStoppingStateResponse][google.cloud.ml.v1.CheckTrialEarlyStoppingStateResponse].
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_check_trial_early_stopping_state():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.CheckTrialEarlyStoppingStateRequest(
+                    trial_name="trial_name_value",
+                )
+
+                # Make the request
+                operation = client.check_trial_early_stopping_state(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CheckTrialEarlyStoppingStateRequest, dict]):
                 The request object. Request message for
@@ -1340,7 +1706,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1363,6 +1734,25 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> study.Trial:
         r"""Stops a Trial.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_stop_trial():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.StopTrialRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.stop_trial(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.StopTrialRequest, dict]):
                 The request object. Request message for
@@ -1401,7 +1791,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1420,6 +1815,25 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         pareto-optimal can be checked in wiki page.
         https://en.wikipedia.org/wiki/Pareto_efficiency
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_optimal_trials():
+                # Create a client
+                client = aiplatform_v1beta1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListOptimalTrialsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.list_optimal_trials(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListOptimalTrialsRequest, dict]):
                 The request object. Request message for
@@ -1475,7 +1889,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
